#ifndef EFFECTS_H
#define EFFECTS_H

#include <GL/glut.h>
#include <vector>
#include "vec.h"

#define RAND_UNIT (rand()/(float)RAND_MAX)
#define COLOUR 1
using namespace std;
const int cMax = 1000;

//particle struct for engine, explosion and plasma
struct Particle{
	vec2f Pos;
	vec2f Vel;
	float life;
};
//particle struct for the stars
struct starParticle{
	vec2f Pos;
	int size;
};

//Class for the engine attached to the ship
class Engine{
private:
	vector<Particle> points;
	int count;

public: 
	Engine();
	//draws all the points to the screen
	void drawPoints();
	//update the points positions and life value, and determine if it should die
	void updatePoints(float dt);
	//creates a point
	void createPoint(vec2f posSet, float heading);
	//deletes the point 'i'
	void deletePoint(int i);
	//clears the points structure
	void erase();
};

//Class for the explosions that happen when asteroids split/die
class Explosion{
private:
	vector<Particle> points;
	int count;

public:
	Explosion();
	//creates a cluster of points around the position posSet
	void explode(vec2f posSet);
	void drawPoints();
	void updatePoints(float dt);
	void createPoint(vec2f posSet, float heading);
	void deletePoint(int i);
	void erase();
};

//Class for the plasma effect that comes off the bullets
class Plasma{
private:
	vector<Particle> points;
	int count;
public:
	Plasma();
	~Plasma();
	void drawPoints();
	void updatePoints(float dt);
	void createPoint(vec2f posSet, float heading);
	void deletePoint(int i);
	void erase();
};

//Class that holds all the stars
class Star{
private:
	vector<starParticle> points;
	int count;
	vec2f levelSize;
public:
	Star();
	~Star();
	//randomly generates the stars at positions
	void createStars();
	void drawPoints();
	void createPoint();
	void deletePoint(int i);
	void erase();
	void setSize(vec2f boundsSet);
};


class shipExplosion{
private:
	vector<Particle> points;
	int count;

public:
	shipExplosion();
	//creates a cluster of points around the position posSet
	void explode(vec2f posSet);
	void drawPoints();
	void updatePoints(float dt);
	void createPoint(vec2f posSet, float heading);
	void deletePoint(int i);
	void erase();
};
#endif
